==> meyda-5.4.0.tgz: package/README.md <==
# meyda

![Build Status][build-status-image]

Meyda is a Javascript audio feature extraction library. Meyda supports both offline feature extraction as well as real-time feature extraction using the [Web Audio API][web-audio-api]. We wrote a paper about it, which is available [here][meyda-paper].

Would you like your Meyda project to be featured in our [user showcase]? [Please let us know!](https://github.com/meyda/meyda/issues/new?assignees=&labels=Showcase+Request&template=showcase-application.md&title=)

Want to ask questions, or chat about Meyda? Check out our [slack channel] on the Web Audio Slack Team. You'll need to [sign up here][web-audio-slack-team-signup] before you can join.

[hughrawlinson][hugh-github] | [nevosegal][nevo-github] | [jakubfiala][jakub-github] | [2xAA][2xaa-github]

### Usage

Please see [the documentation][docs] for setup and usage instructions.

### Contributing

Please see [our contributor guidelines][contributing] for guidelines about contributing, and bear in mind that we adhere to the [Contributor Covenant][contributor-covenant]

[build-status-image]: https://img.shields.io/github/checks-status/meyda/meyda/main
[web-audio-api]: https://github.com/WebAudio/web-audio-api
[meyda-paper]: http://doc.gold.ac.uk/~mu202hr/publications/RawlinsonSegalFiala_WAC2015.pdf
[hugh-github]: https://github.com/hughrawlinson
[nevo-github]: https://github.com/nevosegal
[jakub-github]: https://github.com/jakubfiala
[2xaa-github]: https://github.com/2xaa
[contributing]: https://meyda.js.org/guides/contributing
[contributor-covenant]: https://github.com/meyda/meyda/wiki/Contributor-Covenant
[docs]: https://meyda.js.org/
[slack channel]: https://web-audio.slack.com/messages/C51A03LBS/
[web-audio-slack-team-signup]: https://web-audio-slackin.herokuapp.com/
[user showcase]: https://meyda.js.org/showcase

==> meyda-5.6.0.tgz: package/README.md <==
# meyda

![Build Status][build-status-image]

Meyda is a Javascript audio feature extraction library. Meyda supports both offline feature extraction as well as real-time feature extraction using the [Web Audio API][web-audio-api]. We wrote a paper about it, which is available [here][meyda-paper].

Would you like your Meyda project to be featured in our [user showcase]? [Please let us know!](https://github.com/meyda/meyda/issues/new?assignees=&labels=Showcase+Request&template=showcase-application.md&title=)

Want to ask questions, or chat about Meyda? Check out our [slack channel] on the Web Audio Slack Team. You'll need to [sign up here][web-audio-slack-team-signup] before you can join.

[hughrawlinson][hugh-github] | [nevosegal][nevo-github] | [jakubfiala][jakub-github] | [2xAA][2xaa-github]

### Usage

Please see [the documentation][docs] for setup and usage instructions.

### Contributing

Please see [our contributor guidelines][contributing] for guidelines about contributing, and bear in mind that we adhere to the [Contributor Covenant][contributor-covenant]

[build-status-image]: https://img.shields.io/github/checks-status/meyda/meyda/main
[web-audio-api]: https://github.com/WebAudio/web-audio-api
[meyda-paper]: https://wac.ircam.fr/pdf/wac15_submission_17.pdf
[hugh-github]: https://github.com/hughrawlinson
[nevo-github]: https://github.com/nevosegal
[jakub-github]: https://github.com/jakubfiala
[2xaa-github]: https://github.com/2xaa
[contributing]: https://meyda.js.org/guides/contributing
[contributor-covenant]: https://github.com/meyda/meyda/wiki/Contributor-Covenant
[docs]: https://meyda.js.org/
[slack channel]: https://web-audio.slack.com/messages/C51A03LBS/
[web-audio-slack-team-signup]: https://web-audio-slackin.herokuapp.com/
[user showcase]: https://meyda.js.org/showcase
